@@ -68,7 +68,7 @@ except ImportError:
 
 # Cython
 
-CYTHON = '0.29.36'
+CYTHON = '3.0.0'
 
 def cython_req():
     return CYTHON
@@ -100,8 +100,8 @@ def cython_chk(VERSION, verbose=True):
         return False
     REQUIRED = Version(VERSION)
     PROVIDED = Version(m.groups()[0])
-    if PROVIDED != REQUIRED:
-        warn("You need Cython == {0} (you have version {1})"
+    if PROVIDED < REQUIRED:
+        warn("You need Cython >= {0} (you have version {1})"
              .format(VERSION, CYTHON_VERSION))
         return False
     #
@@ -130,7 +130,7 @@ def cython_run(
             return
     finally:
         os.chdir(cwd)
-    require = 'Cython == %s' % VERSION
+    require = 'Cython >= %s' % VERSION
     if setuptools and not cython_chk(VERSION, verbose=False):
         if sys.modules.get('Cython'):
             removed = getattr(sys.modules['Cython'], '__version__', '')
@@ -177,14 +177,14 @@ def fix_config_vars(names, values):
         if 'ARCHFLAGS' in os.environ:
             ARCHFLAGS = os.environ['ARCHFLAGS']
             for i, flag in enumerate(list(values)):
-                flag, count = re.subn('-arch\s+\w+', ' ', str(flag))
+                flag, count = re.subn(r'-arch\s+\w+', ' ', str(flag))
                 if count and ARCHFLAGS:
                     flag = flag + ' ' + ARCHFLAGS
                 values[i] = flag
         if 'SDKROOT' in os.environ:
             SDKROOT = os.environ['SDKROOT']
             for i, flag in enumerate(list(values)):
-                flag, count = re.subn('-isysroot [^ \t]*', ' ', str(flag))
+                flag, count = re.subn(r'-isysroot [^ \t]*', ' ', str(flag))
                 if count and SDKROOT:
                     flag = flag + ' ' + '-isysroot ' + SDKROOT
                 values[i] = flag
@@ -518,15 +518,28 @@ class config(_config):
 
 class build(_build):
 
-    user_options = _build.user_options + cmd_petsc_opts
+    user_options = _build.user_options
+    user_options += [(
+        'inplace',
+        'i',
+        "ignore build-lib and put compiled extensions into the source "
+        "directory alongside your pure Python modules",
+    )]
+    user_options += cmd_petsc_opts
+
+    boolean_options = _build.boolean_options
+    boolean_options += ['inplace']
 
     def initialize_options(self):
         _build.initialize_options(self)
+        self.inplace = None
         self.petsc_dir  = None
         self.petsc_arch = None
 
     def finalize_options(self):
         _build.finalize_options(self)
+        if self.inplace is None:
+            self.inplace = False
         self.set_undefined_options('config',
                                    ('petsc_dir',  'petsc_dir'),
                                    ('petsc_arch', 'petsc_arch'))
@@ -573,12 +586,14 @@ class build_ext(_build_ext):
 
     def initialize_options(self):
         _build_ext.initialize_options(self)
+        self.inplace = None
         self.petsc_dir  = None
         self.petsc_arch = None
         self._outputs = []
 
     def finalize_options(self):
         _build_ext.finalize_options(self)
+        self.set_undefined_options('build', ('inplace', 'inplace'))
         self.set_undefined_options('build',
                                    ('petsc_dir',  'petsc_dir'),
                                    ('petsc_arch', 'petsc_arch'))
@@ -900,7 +915,7 @@ from distutils.text_file import TextFile
 
 # Regexes needed for parsing Makefile-like syntaxes
 import re as _re
-_variable_rx = _re.compile("([a-zA-Z][a-zA-Z0-9_]+)\s*=\s*(.*)")
+_variable_rx = _re.compile(r"([a-zA-Z][a-zA-Z0-9_]+)\s*=\s*(.*)")
 _findvar1_rx = _re.compile(r"\$\(([A-Za-z][A-Za-z0-9_]*)\)")
 _findvar2_rx = _re.compile(r"\${([A-Za-z][A-Za-z0-9_]*)}")
 
